==> haskell-type-errors-0.2.0.2-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-errors
version:              0.2.0.2
visibility:           public
id:                   type-errors-0.2.0.2-705cnfiU04q578rJ0cfnxn
key:                  type-errors-0.2.0.2-705cnfiU04q578rJ0cfnxn
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/isovector/type-errors#readme
synopsis:             Tools for writing better type errors
description:
    Please see the README on GitHub at <https://github.com/isovector/type-errors#readme>

category:             Type
abi:                  ac72f1fed81ca2e9e03152f74725d822
exposed:              True
exposed-modules:      Type.Errors
hidden-modules:       Paths_type_errors
import-dirs:          /usr/lib/ghc-9.2.8/site-local/type-errors-0.2.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/type-errors-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors
hs-libraries:         HStype-errors-0.2.0.2-705cnfiU04q578rJ0cfnxn
depends:
    base-4.16.4.0 first-class-families-0.8.1.0-HHyhV8WJrTPJ5U0bP9g39Z
    syb-0.7.2.4-KjjXDkbXsb76a0JbGOnZpL template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu

haddock-interfaces:   /usr/share/doc/haskell-type-errors/html/type-errors.haddock
haddock-html:         /usr/share/doc/haskell-type-errors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-errors-0.2.0.2-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-errors
version:              0.2.0.2
visibility:           public
id:                   type-errors-0.2.0.2-2hwlOxWC3779yNQN3ZrTtb
key:                  type-errors-0.2.0.2-2hwlOxWC3779yNQN3ZrTtb
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/isovector/type-errors#readme
synopsis:             Tools for writing better type errors
description:
    Please see the README on GitHub at <https://github.com/isovector/type-errors#readme>

category:             Type
abi:                  a640224f71c9c11e2e63f7bac1b3fbd7
exposed:              True
exposed-modules:      Type.Errors
hidden-modules:       Paths_type_errors
import-dirs:          /usr/lib/ghc-9.2.8/site-local/type-errors-0.2.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/type-errors-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors
hs-libraries:         HStype-errors-0.2.0.2-2hwlOxWC3779yNQN3ZrTtb
depends:
    base-4.16.4.0 first-class-families-0.8.1.0-HHyhV8WJrTPJ5U0bP9g39Z
    syb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu

haddock-interfaces:   /usr/share/doc/haskell-type-errors/html/type-errors.haddock
haddock-html:         /usr/share/doc/haskell-type-errors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
